@@ -7,6 +7,8 @@ use std::fmt::{Display, Error, Formatter};
 /// General settings structure.
 #[file]
 pub struct Settings {
+    /// Optional limit on number of threads to use.
+    num_threads: Option<usize>,
     /// Number of tracers to simulate in each thread block.
     block_size: usize,
     /// Bump distance (m).
@@ -18,6 +20,7 @@ pub struct Settings {
 }
 
 impl Settings {
+    clone!(num_threads, Option<usize>);
     clone!(block_size, usize);
     clone!(bump_dist, f64);
     clone!(loop_limit, u64);
@@ -26,12 +29,20 @@ impl Settings {
     /// Construct a new instance.
     #[inline]
     #[must_use]
-    pub fn new(block_size: usize, bump_dist: f64, loop_limit: u64, min_weight: f64) -> Self {
+    pub fn new(
+        num_threads: Option<usize>,
+        block_size: usize,
+        bump_dist: f64,
+        loop_limit: u64,
+        min_weight: f64,
+    ) -> Self {
+        debug_assert!(num_threads.is_none() || num_threads.unwrap() >= 1);
         debug_assert!(block_size > 0);
         debug_assert!(bump_dist > 0.0);
         debug_assert!(min_weight >= 0.0);
 
         Self {
+            num_threads,
             block_size,
             bump_dist,
             loop_limit,
@@ -44,6 +55,11 @@ impl Display for Settings {
     #[inline]
     fn fmt(&self, fmt: &mut Formatter) -> Result<(), Error> {
         writeln!(fmt, "...")?;
+        if let Some(num_threads) = self.num_threads {
+            fmt_report!(fmt, num_threads, "num_threads");
+        } else {
+            fmt_report!(fmt, "unlimited", "num_threads");
+        }
         fmt_report!(fmt, self.block_size, "block size");
         fmt_report!(fmt, self.bump_dist, "bump distance");
         fmt_report!(fmt, self.loop_limit, "loop limit");
